﻿namespace YouTube_Tag_Viewer.Controls
{
	using System.Drawing;
	using System.Windows.Forms;
	
	/// <summary>
	/// A dark button.
	/// </summary>
	public class DarkButton : Control
	{
		bool mouseOver, mouseDown;
		
		public DarkButton()
		{
			Font = new Font("Segoe UI", 9.25f);
			mouseOver = mouseDown;
			
			SetStyle(ControlStyles.AllPaintingInWmPaint | ControlStyles.OptimizedDoubleBuffer | ControlStyles.ResizeRedraw | ControlStyles.UserPaint, true);
			UpdateStyles();
			DoubleBuffered = true;
		}
		
		protected override void OnMouseEnter(System.EventArgs e)
		{
			mouseOver = true;
			Refresh();
		}
		
		protected override void OnMouseLeave(System.EventArgs e)
		{
			mouseOver = mouseDown = false;
			Refresh();
		}
		
		protected override void OnMouseDown(MouseEventArgs e)
		{
			mouseDown = true;
			Refresh();
		}
		
		protected override void OnMouseUp(MouseEventArgs e)
		{
			mouseDown = false;
			Refresh();
		}
		
		protected override void OnPaint(PaintEventArgs e)
		{
			Color bg;
			
			if (mouseDown)
				bg = Color.FromArgb(40, 40, 40);
			else if (mouseOver)
				bg = Color.FromArgb(56, 56, 56);
			else bg = Color.FromArgb(48, 48, 48);
			
			e.Graphics.Clear(bg);
			
			SizeF textSize = e.Graphics.MeasureString(Text, Font);
			PointF textPos = new PointF(Width / 2.0f - textSize.Width / 2.0f, Height / 2.0f - textSize.Height / 2.0f);
			
			e.Graphics.DrawString(Text, Font, Brushes.White, textPos);
			
			using (var p = new Pen(Color.FromArgb(32, 32, 32)))
				e.Graphics.DrawRectangle(p, new Rectangle(0, 0, Width - 1, Height - 1));
		}
	}
}
