﻿namespace YouTube_Tag_Viewer
{
	using System;
	using System.ComponentModel;
	using System.Net;
	using System.Text;
	using System.Windows.Forms;
	
	/// <summary>
	/// MainForm of the application.
	/// </summary>
	public partial class MainForm : Form
	{		
		string text = string.Empty;
		
		public MainForm()
		{
			//
			// The InitializeComponent() call is required for Windows Forms designer support.
			//
			InitializeComponent();
		}
		
		#region Methods
		
		bool CheckInput()
		{
			if (string.IsNullOrWhiteSpace(txtUrl.Text))
			{
				MessageBox.Show("The URL can not be empty!", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				return false;
			}
			
			return true;
		}
		
		void LockUI()
		{
			UseWaitCursor = true;
			txtUrl.Enabled = false;
			btnDownload.Enabled = false;
		}
		
		void FreeUI()
		{
			UseWaitCursor = false;
			txtUrl.Enabled = true;
			btnDownload.Enabled = true;
		}
		
		#endregion
		
		void BtnDownloadClick(object sender, EventArgs e)
		{
			if (!CheckInput())
				return;
			LockUI();
			
			using (var bw = new BackgroundWorker())
			{
				bw.DoWork += bw_DoWork;
				bw.RunWorkerCompleted += bw_RunWorkerCompleted;				
				
				bw.RunWorkerAsync();
			}
		}
		
		#region Background Worker

		void bw_DoWork(object sender, DoWorkEventArgs e)
		{
			string html = string.Empty;
						
			using (WebClient wc = new WebClient())
			{				
				wc.Encoding = Encoding.UTF8;
				try
				{
					html = wc.DownloadString(txtUrl.Text);
				}
				catch (WebException) 
				{
					MessageBox.Show("An error occured trying to download the information.\nCheck if your PC is connected to the internet and if you entered the correct URL.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					return;
				}
				catch (Exception)
				{
					MessageBox.Show("An unexpected error occured trying to download the information.", "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
					return;
				}
			}
			
			int si = 0, length = 0;
			StringBuilder sb = new StringBuilder();

			// Get video title of the <title>-Attribute
			si = html.IndexOf("<title>") + 7;
			length = html.IndexOf("</title>") - si - 10; // -10 to filter the " - YouTube"
			string title = html.Substring(si, length);			
			sb.AppendLine("Title:\t" + title);
			
			// Get the creators name
			si = html.IndexOf("<div class=\"yt-user-info\">");
			si = html.IndexOf("data-ytid", si);
			si = html.IndexOf('>', si) + 1;
			length = html.IndexOf('<', si + 1) - si;
			string creator = html.Substring(si, length);
			sb.Append("Creator:\t" + creator);
			
			// Get the subscriber count
			si = html.IndexOf("<span class=\"yt-subscription-button-subscriber-count-branded-horizontal yt-subscriber-count\"");
			si = html.IndexOf('>', si) + 1;
			length = html.IndexOf('<', si) - si;
			string subs = html.Substring(si, length);
			sb.AppendLine("   (" + subs + " Subs)");
			
			// Get the view count
			si = html.IndexOf("<div class=\"watch-view-count\">");
			si = html.IndexOf('>', si) + 1;
			length = html.IndexOf("</div>", si) - si - 8;
			string views = html.Substring(si, length);
			sb.AppendLine("Views:\t" + views);
						
			// Get the tags
			si = html.IndexOf("<script>var ytplayer = ytplayer || {};");
			length = html.IndexOf("</script>", si) - si;
			
			string script = html.Substring(si, length);
			si = script.IndexOf("\"keywords\":") + 12;
			length = script.IndexOf('"', si) - si;
			string tags = script.Substring(si, length);
			sb.AppendLine("\nTags:\t" + tags);
			
			// Save the text to print in the text box
			text = sb.ToString();
		}

		void bw_RunWorkerCompleted(object sender, RunWorkerCompletedEventArgs e)
		{			
			txtInformation.Text = text;
			FreeUI();
		}
		
		#endregion
	}
}
